[![Join the chat at https://gitter.im/tek/ribosome](https://badges.gitter.im/tek/ribosome.svg)](https://gitter.im/tek/ribosome?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)

# Under Construction
The library has changed a lot, the readme will get updated soon.
